@@ -9,6 +9,8 @@ if not os.getenv("READ_THE_DOCS"):
         EditPartitionRequest,
         SearchPartitionsRequest,
     )
+    from cognite.seismic.protos.types_pb2 import CRS, Geometry, GeoJson, Wkt
+    from google.protobuf.struct_pb2 import Struct
 else:
     from cognite.seismic._api.shims import CoverageSpec, Identifier
 
@@ -71,7 +73,7 @@ def get_search_spec(
 
 def get_coverage_spec(crs: Optional[str] = None, format: Optional[str] = None) -> CoverageSpec:
     """Turns an optional crs and an optional string into a CoverageSpec."""
-    if format == None:
+    if format is None:
         format = "wkt"
 
     if format == "wkt":
@@ -80,3 +82,21 @@ def get_coverage_spec(crs: Optional[str] = None, format: Optional[str] = None) -
         return CoverageSpec(crs=crs, format=1)
     else:
         raise ValueError(f"Unknown format {format}")
+
+
+def make_geometry(crs: Optional[str] = None, wkt: Optional[str] = None, geo_json: Optional[dict] = None):
+    """Make a Geometry proto from python sdk arguments"""
+
+    if wkt is not None and geo_json is not None:
+        raise ValueError("Provide either wkt or gejson, not both")
+
+    wrapped_crs = None if crs is None else CRS(crs=crs)
+
+    if wkt is not None:
+        return Geometry(crs=wrapped_crs, wkt=Wkt(geometry=wkt))
+    elif geo_json is not None:
+        geo_json_struct = Struct()
+        geo_json_struct.update(geo_json)
+        return Geometry(crs=wrapped_crs, geo=GeoJson(json=geo_json_struct))
+    else:
+        return None
